@@ -83,7 +83,8 @@ class Skeleton:
     def get_joint_names(self) -> List[Text]:
         return [k3d.text(
             text=self.joint_set.names[i],
-            position=self.joint_coordinates[i])
+            position=self.joint_coordinates[i],
+            size=0.6, label_box=False)
             for i in range(self.joint_set.number_of_joints)
         ]
 
